@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-bookmark-in-project
 ;; Keywords: convenience
-;; Package-Version: 20251126.519
-;; Package-Revision: 9602be7da3fb
+;; Package-Version: 20260108.1305
+;; Package-Revision: bf923ddd3e74
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -16,11 +16,11 @@
 ;; This package adds functionality for quickly accessing bookmarks within the current projects.
 ;;
 
-;;; Usage
+;;; Usage:
 
-;; To use this package, bind keys to: \\[bookmark-in-project-toggle]
-;; \\[bookmark-in-project-jump-next] \\[bookmark-in-project-jump-previous] and
-;; \\[bookmark-in-project-jump].
+;; To use this package, bind keys to: `bookmark-in-project-toggle'
+;; `bookmark-in-project-jump-next' `bookmark-in-project-jump-previous' and
+;; `bookmark-in-project-jump'.
 
 ;;; Code:
 
@@ -75,7 +75,6 @@ set to `identity' to use plain text."
 
 (defcustom bookmark-in-project-verbose-toggle t
   "Show messages when toggling bookmarks on/off."
-
   :type 'boolean)
 (defcustom bookmark-in-project-verbose-cycle t
   "Show messages when cycling between bookmarks."
@@ -111,7 +110,7 @@ This is done without adjusting trailing slashes or following links."
 (defun bookmark-in-project--nth-elt (element xs &rest args)
   "Return zero-indexed position of ELEMENT in list XS, or nil if absent.
 Optional ARGS, may contain :test keyword argument,
-it's value is used instead of `equal' for comparison,
+its value is used instead of `equal' for comparison,
 where the first argument is always ELEMENT, the second is a member of XS."
   (declare (important-return-value t))
   (let ((index 0)
@@ -124,7 +123,7 @@ where the first argument is always ELEMENT, the second is a member of XS."
 (defun bookmark-in-project--nth-vec (element xs &rest args)
   "Return zero-indexed position of ELEMENT in vector XS, or nil if absent.
 Optional ARGS, may contain :test keyword argument,
-it's value is used instead of `equal' for comparison,
+its value is used instead of `equal' for comparison,
 where the first argument is always ELEMENT, the second is a member of XS."
   (declare (important-return-value t))
   (let ((xs-length (length xs))
@@ -144,7 +143,7 @@ where the first argument is always ELEMENT, the second is a member of XS."
   (unless buffer-file-name
     (error "Buffer not visiting a file or directory")))
 
-(defun bookmark-in-project--repr-precent (value-fraction value-total)
+(defun bookmark-in-project--repr-percent (value-fraction value-total)
   "Return a percentage string from VALUE-FRACTION in VALUE-TOTAL."
   (declare (important-return-value t))
   (concat
@@ -161,14 +160,12 @@ where the first argument is always ELEMENT, the second is a member of XS."
   "Run BODY with messages suppressed."
   `(let ((inhibit-message t)
          (message-log-max nil))
-     (progn
-       ,@body)))
+     ,@body))
 
 (defmacro bookmark-in-project--with-save-deferred (&rest body)
-  "Execute BODY with WHERE advice on FN-ORIG temporarily enabled."
+  "Execute BODY with bookmark-saving deferred."
   `(prog1 (let ((bookmark-save-flag nil))
-            (progn
-              ,@body))
+            ,@body)
      (when (bookmark-time-to-save-p)
        (bookmark-save))))
 
@@ -287,12 +284,12 @@ This checks `ffip', `projectile', `project' & `vc' root."
          (alist
           (setq pair (car-safe alist))
           (setq alist (cdr-safe alist))
-          (incf pos-depth)
           (cond
            ((atom pair)) ; Skip anything not a cons.
            ((imenu--subalist-p pair)
             (setq imstack (cons alist imstack))
-            (setq alist (cdr pair)))
+            (setq alist (cdr pair))
+            (incf pos-depth))
            ((number-or-marker-p (setq mark (cdr pair)))
             ;; Ensure the next item isn't nested.
             (when (<= pos-depth pos-best-depth)
@@ -329,7 +326,7 @@ This checks `ffip', `projectile', `project' & `vc' root."
             (let ((lines-all (count-lines pos-best pos-next)))
               (setq text
                     (concat
-                     text " [" (bookmark-in-project--repr-precent lines-rel lines-all) "]")))))
+                     text " [" (bookmark-in-project--repr-percent lines-rel lines-all) "]")))))
 
         text))
      (t ; No context, show the percent in the file.
@@ -337,16 +334,16 @@ This checks `ffip', `projectile', `project' & `vc' root."
       ;; Otherwise there is no context given which seems strange.
       (let ((lines-rel (count-lines (point-min) pos))
             (lines-all (count-lines (point-min) (point-max))))
-        (concat "[" (bookmark-in-project--repr-precent lines-rel lines-all) "]"))))))
+        (concat "[" (bookmark-in-project--repr-percent lines-rel lines-all) "]"))))))
 
 (defun bookmark-in-project-name-default-with-line ()
-  "Return the name used to create ."
+  "Return the name used to create the bookmark with the line number."
   (declare (important-return-value t))
   (let ((filepath (bookmark-in-project--canonicalize-path (buffer-file-name))))
     (format "%s: %d" filepath (line-number-at-pos (point) t))))
 
 (defun bookmark-in-project-name-default-with-context ()
-  "Return the name used to create ."
+  "Return the name used to create the bookmark with contextual information."
   (declare (important-return-value t))
   (let ((filepath (bookmark-in-project--canonicalize-path (buffer-file-name))))
     (format "%s: %s" filepath (bookmark-in-project--context-id-at-point (point)))))
@@ -467,7 +464,9 @@ Note that if the file is not opened, it's assumed not to be narrowed."
                     (point-narrow-max (point-max)))
                 (save-restriction
                   (widen)
-                  (bookmark-jump (car item))
+                  ;; Instead of calling `bookmark-jump', call this lower level function
+                  ;; so as not to create messages or set the `bookmark-current-bookmark'.
+                  (bookmark-handle-bookmark (car item))
                   (unless (and (<= point-narrow-min (point)) (<= (point) point-narrow-max))
                     (setq visible nil)))))))))
     visible))
@@ -547,7 +546,7 @@ Or DEFAULT if not found."
 
 (defun bookmark-in-project--item-get-position (item)
   "Return the position of bookmark ITEM.
-Note that this must only run on the for bookmarks in the current buffer,
+Note that this must only run for bookmarks in the current buffer,
 otherwise it will switch the buffer."
   (declare (important-return-value t))
   ;; Note that edits to the document mean: (alist-get 'position item)
@@ -561,7 +560,7 @@ otherwise it will switch the buffer."
 ;; Doesn't attempt to handle errors, just skip them.
 (defun bookmark-in-project--item-get-position-or-nil (item)
   "Return the position of bookmark ITEM.
-Note that this must only run on the for bookmarks in the current buffer,
+Note that this must only run for bookmarks in the current buffer,
 otherwise it will switch the buffer."
   (declare (important-return-value t))
   ;; Note that edits to the document mean: (alist-get 'position item)
@@ -784,7 +783,7 @@ Returning the next bookmark or nil."
     (while (< i filepath-bm-list-pairs-len)
       (pcase-let ((`(,filepath-iter . ,pi-list-iter) (aref filepath-pi-list-pairs i)))
         (cond
-         ;; The file pas been met, find the index within the list.
+         ;; The file has been met, find the index within the list.
          ((string-equal filepath-iter filepath-item)
           (setq pi-list-iter (bookmark-in-project--pi-list-sorted-by-pos pi-list-iter))
           ;; The result is never nil, no need to account for this case.
@@ -845,7 +844,7 @@ Returning the next bookmark or nil."
                                              (t
                                               (format " (%d skipped)" skip))))))))
        (t
-        ;; Note that his is  unlikely.
+        ;; Note that this is unlikely.
         (when bookmark-in-project-verbose-cycle
           (bookmark-in-project--message "unable to cycle %d bookmarks in %S!"
                                         (length bm-list)
@@ -938,7 +937,7 @@ only bookmarks on the current line will be considered."
         item-found)))))
 
 (defun bookmark-in-project--remap-name (bm-list-src bm-list-dst name)
-  "Translate NAME from it's value in BM-LIST-SRC to it's value in BM-LIST-DST."
+  "Translate NAME from its value in BM-LIST-SRC to its value in BM-LIST-DST."
   (declare (important-return-value t))
   (let ((result name))
     (while bm-list-src
